summaryrefslogtreecommitdiff
path: root/libpod/container.go
diff options
context:
space:
mode:
authorMatthew Heon <matthew.heon@pm.me>2019-03-26 13:55:19 -0400
committerMatthew Heon <matthew.heon@pm.me>2019-03-27 10:12:18 -0400
commit0cd92eae65b31cdbaa19e3cccb0e3234196a6d17 (patch)
tree97ad5dec432154ba5bc88e758d5110494d45d35f /libpod/container.go
parent86f03e0e526bbf39ea8a6cb18e3067a7e37bfd89 (diff)
downloadpodman-0cd92eae65b31cdbaa19e3cccb0e3234196a6d17.tar.gz
podman-0cd92eae65b31cdbaa19e3cccb0e3234196a6d17.tar.bz2
podman-0cd92eae65b31cdbaa19e3cccb0e3234196a6d17.zip
Resolve review comments
Signed-off-by: Matthew Heon <matthew.heon@pm.me>
Diffstat (limited to 'libpod/container.go')
-rw-r--r--libpod/container.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/libpod/container.go b/libpod/container.go
index 866cf5c58..806e75c63 100644
--- a/libpod/container.go
+++ b/libpod/container.go
@@ -293,10 +293,10 @@ type ContainerConfig struct {
// namespace
// These are not used unless CreateNetNS is true
PortMappings []ocicni.PortMapping `json:"portMappings,omitempty"`
// NoCreateResolvConf indicates that resolv.conf should not be
// bind-mounted inside the container.
// Conflicts with DNSServer, DNSSearch, DNSOption.
- NoCreateResolvConf bool
+ UseImageResolvConf bool
// DNS servers to use in container resolv.conf
// Will override servers in host resolv if set
DNSServer []net.IP `json:"dnsServer,omitempty"`
@@ -306,10 +306,10 @@ type ContainerConfig struct {
// DNS options to be set in container resolv.conf
// With override options in host resolv if set
DNSOption []string `json:"dnsOption,omitempty"`
// NoCreateHosts indicates that /etc/hosts should not be
// bind-mounted inside the container.
// Conflicts with HostAdd.
- NoCreateHosts bool
+ UseImageHosts bool
// Hosts to add in container
// Will be appended to host's host file
HostAdd []string `json:"hostsAdd,omitempty"`
@@ -293,10 +293,10 @@ type ContainerConfig struct {
// These are not used unless CreateNetNS is true
PortMappings []ocicni.PortMapping `json:"portMappings,omitempty"`
- // NoCreateResolvConf indicates that resolv.conf should not be
+ // UseImageResolvConf indicates that resolv.conf should not be
// bind-mounted inside the container.
// Conflicts with DNSServer, DNSSearch, DNSOption.
@@ -306,10 +306,10 @@ type ContainerConfig struct {
// With override options in host resolv if set
DNSOption []string `json:"dnsOption,omitempty"`
- // NoCreateHosts indicates that /etc/hosts should not be
+ // UseImageHosts indicates that /etc/hosts should not be
// bind-mounted inside the container.
// Conflicts with HostAdd.